# -*- coding: utf-8 -*-
# Copyright 2024 Cohesity Inc.

import logging
from cohesity_management_sdk.api_helper import APIHelper
from cohesity_management_sdk.configuration import Configuration
from cohesity_management_sdk.controllers.base_controller import BaseController
from cohesity_management_sdk.http.auth.auth_manager import AuthManager
from cohesity_management_sdk.exceptions.request_error_error_exception import RequestErrorErrorException


class LicenseAgreementController(BaseController):
    """A Controller to access Endpoints in the cohesity_management_sdk API."""
    def __init__(self, config=None, client=None, call_back=None):
        super(LicenseAgreementController, self).__init__(client, call_back)
        self.logger = logging.getLogger(__name__)
        self.config = config

    
    def accept_license(self, body):
        """Does a POST request to /public/licenseAgreement.

        Args:
            body (EulaConfig): Request to accept EULA.

        Returns:
            void: Response from the API. No Content

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """
        try:
            self.logger.info('accept_license called.')

            # Validate required parameters
            self.logger.info(
                'Validating required parameters for accept_license.')
            self.validate_parameters(body=body)

            # Prepare query URL
            self.logger.info('Preparing query URL for accept_license.')
            _url_path = '/public/licenseAgreement'
            _query_builder = self.config.get_base_uri()
            _query_builder += _url_path
            _query_url = APIHelper.clean_url(_query_builder)

            # Prepare headers
            self.logger.info('Preparing headers for accept_license.')
            _headers = {
                'accept': 'application/json',
                'content-type': 'application/json; charset=utf-8'
            }

            # Prepare and execute request
            self.logger.info(
                'Preparing and executing request for accept_license.')
            _request = self.http_client.post(
                _query_url,
                headers=_headers,
                parameters=APIHelper.json_serialize(body))
            AuthManager.apply(_request, self.config)
            _context = self.execute_request(_request, name='accept_license')

            # Endpoint and global error handling using HTTP status codes.
            self.logger.info('Validating response for accept_license.')
            if _context.response.status_code == 0:
                raise RequestErrorErrorException('Error', _context)
            self.validate_response(_context)

        except Exception as e:
            self.logger.error(e, exc_info=True)
            raise

 